summaryrefslogtreecommitdiff
path: root/indra/newview/llscriptfloater.cpp
diff options
context:
space:
mode:
authorRunitai <>2009-12-15 16:53:29 -0600
committerRunitai <>2009-12-15 16:53:29 -0600
commit1f8ad2651d82b81fc85d91f3d48663430427537e (patch)
treec4ed86401b803aefdbfaa9eef6f87ecd5567c58d /indra/newview/llscriptfloater.cpp
parenta81a2f19b21134fb52df1e1a735988a04aa0688a (diff)
parent88a146e0bb95476792d0fabedab6d7a41c350949 (diff)
Merge
Diffstat (limited to 'indra/newview/llscriptfloater.cpp')
-rw-r--r--indra/newview/llscriptfloater.cpp30
1 files changed, 28 insertions, 2 deletions
diff --git a/indra/newview/llscriptfloater.cpp b/indra/newview/llscriptfloater.cpp
index 5c4f6e8860..1962d871a6 100644
--- a/indra/newview/llscriptfloater.cpp
+++ b/indra/newview/llscriptfloater.cpp
@@ -66,6 +66,7 @@ LLScriptFloater::LLScriptFloater(const LLSD& key)
: LLDockableFloater(NULL, true, key)
, mScriptForm(NULL)
{
+ setMouseDownCallback(boost::bind(&LLScriptFloater::onMouseDown, this));
}
bool LLScriptFloater::toggle(const LLUUID& object_id)
@@ -180,6 +181,23 @@ void LLScriptFloater::setVisible(BOOL visible)
hideToastsIfNeeded();
}
+void LLScriptFloater::onMouseDown()
+{
+ if(getObjectId().notNull())
+ {
+ // Remove new message icon
+ LLIMChiclet* chiclet = LLBottomTray::getInstance()->getChicletPanel()->findChiclet<LLIMChiclet>(getObjectId());
+ if (chiclet == NULL)
+ {
+ llerror("Dock chiclet for LLScriptFloater doesn't exist", 0);
+ }
+ else
+ {
+ chiclet->setShowNewMessagesIcon(false);
+ }
+ }
+}
+
void LLScriptFloater::hideToastsIfNeeded()
{
using namespace LLNotificationsUI;
@@ -191,6 +209,7 @@ void LLScriptFloater::hideToastsIfNeeded()
if(channel)
{
channel->updateShowToastsState();
+ channel->redrawToasts();
}
}
@@ -217,11 +236,18 @@ void LLScriptFloaterManager::onAddNotification(const LLUUID& notification_id)
script_notification_map_t::iterator it = mNotifications.find(object_id);
if(it != mNotifications.end())
{
+ LLIMChiclet* chiclet = LLBottomTray::getInstance()->getChicletPanel()->findChiclet<LLIMChiclet>(object_id);
+ if(chiclet)
+ {
+ // Pass the new_message icon state further.
+ set_new_message = chiclet->getShowNewMessagesIcon();
+ }
+
LLScriptFloater* floater = LLFloaterReg::findTypedInstance<LLScriptFloater>("script_floater", it->second.notification_id);
if(floater)
{
- // Generate chiclet with a "new message" indicator if a docked window was opened. See EXT-3142.
- set_new_message = floater->isShown();
+ // Generate chiclet with a "new message" indicator if a docked window was opened but not in focus. See EXT-3142.
+ set_new_message |= !floater->hasFocus();
}
onRemoveNotification(it->second.notification_id);